=========================================
``psyclone.domain.lfric.lfric_constants``
=========================================

.. automodule:: psyclone.domain.lfric.lfric_constants

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.lfric.lfric_constants


Classes
=======

- :py:class:`LFRicConstants`:
  This class stores all LFRic constants. Note that some constants


.. autoclass:: LFRicConstants
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: LFRicConstants
      :parts: 1
